@@ -178,8 +178,8 @@ static int _gnutls_ssl3_finished(GNUTLS_STATE state, int type, int skip,
 int _gnutls_finished(GNUTLS_STATE state, int type, int skip, void *ret)
 {
 	int siz;
-	GNUTLS_MAC_HANDLE td;
-	GNUTLS_MAC_HANDLE td2;
+	GNUTLS_HASH_HANDLE td;
+	GNUTLS_HASH_HANDLE td2;
 	char tmp[MAX_HASH_SIZE];
 	opaque concat[36];
 	opaque *mesg, *data;
@@ -1354,7 +1354,6 @@ static int _gnutls_send_client_hello(GNUTLS_STATE state, int again)
 			hver =
 			    state->gnutls_internals.
 			    resumed_security_parameters.version;
-			_gnutls_set_current_version(state, hver);
 		}
 
 		if (hver <= 0) {
@@ -1367,6 +1366,21 @@ static int _gnutls_send_client_hello(GNUTLS_STATE state, int again)
 		data[pos++] = _gnutls_version_get_major(hver);
 		data[pos++] = _gnutls_version_get_minor(hver);
 
+		/* Set the version we advertized as maximum 
+		 * (RSA uses it).
+		 */
+		_gnutls_set_adv_version( state, hver);
+
+		/* Some implementations do not interoperate if we send a
+		 * different version in the record layer.
+		 * It seems they prefer to read the record's version
+		 * as the one we actually requested.
+		 *  The proper behaviour is to use the one in the client hello 
+		 * handshake packet and ignore the one in the packet's record 
+		 * header.
+		 */
+		_gnutls_set_current_version(state, hver);
+
 		/* In order to know when this session was initiated.
 		 */
 		state->security_parameters.timestamp = time(NULL);
@@ -2272,3 +2286,13 @@ void gnutls_handshake_set_max_data_buffer_size(GNUTLS_STATE state, int max)
 {
 	state->gnutls_internals.max_handshake_data_buffer_size = max;
 }
+
+void _gnutls_set_adv_version( GNUTLS_STATE state, GNUTLS_Version ver) {
+	set_adv_version( state, _gnutls_version_get_major(ver), _gnutls_version_get_minor(ver));
+}
+
+GNUTLS_Version _gnutls_get_adv_version( GNUTLS_STATE state) {
+	return _gnutls_version_get( _gnutls_get_adv_version_major( state), 
+		_gnutls_get_adv_version_minor( state));
+}
+
