@@ -171,3 +171,39 @@ int gnutls_x509pki_get_certificate_request_status(GNUTLS_STATE state)
 }
 
 
+typedef MACAlgorithm DigestAlgorithm;
+/**
+  * gnutls_fingerprint - This function calculates the fingerprint of the given data
+  * @algo: is a digest algorithm
+  * @data: is the data
+  * @result: is the place where the result will be copied. 
+  * @result_size: should hold the size of the result. The actual size
+  * of the returned result will also be copied there.
+  *
+  * This function will calculate a fingerprint (actually a hash), of the
+  * given data. The result is not printable data. You should convert it
+  * to hex, or to something else printable.
+  * Returns a negative value in case of an error.
+  *
+  **/
+int gnutls_fingerprint(DigestAlgorithm algo, const gnutls_datum* data, char* result, int* result_size)
+{
+	GNUTLS_HASH_HANDLE td;
+	int hash_len = gnutls_hash_get_algo_len(algo);
+	
+	if (hash_len > *result_size || hash_len < 0) {
+		*result_size = hash_len;
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+	*result_size = hash_len;
+	
+	td = gnutls_hash_init( algo);
+	if (td==NULL) return GNUTLS_E_HASH_FAILED;
+	
+	gnutls_hash( td, data->data, data->size);
+	
+	gnutls_hash_deinit( td, result);
+		
+	return 0;
+}
+
